==> spread-5.5.0.34-py3-none-any.whl: spread_core/warehouse/equipment_warehouse.py <==
from spread_core.bam.const import *
from spread_core.bam.engineries import Enginery
from spread_core.bam.recipe import Recipe
from spread_core.bam.subgineries.subginery import Subginery
from spread_core.errors.project_errors import EntityNotPresent


class EquipmentWarehouse:
    __slots__ = ['_project_id', '_entities', '_managers']

    def __init__(self, project_id):
        self._project_id = project_id
        self._entities = {}
        self._managers = {}

    def get_entity(self, entity_id: int):
        try:
            return self._entities[entity_id]
        except KeyError:
            raise EntityNotPresent(f'Entity({entity_id}) is not present')

    def get_recipe(self, manager_id: int, provider_id: int) -> Recipe:
        try:
            return self.get_manager(manager_id)[PROVIDERS][provider_id]
        except KeyError:
            raise EntityNotPresent(f'Provider({provider_id}) is not present')

    def all_entities(self) -> tuple:
        yield from self._entities.values()

    def add_manager(self, _id, _type):
        self._managers[_id] = {ID: _id, TYPE: _type, PROVIDERS: {}}

    def get_manager(self, manager_id: int):
        try:
            return self._managers[manager_id]
        except KeyError:
            raise EntityNotPresent(f'Manager({manager_id}) is not present')

    def add_provider(self, recipe: Recipe):
        self._managers[recipe.manager_id].setdefault(PROVIDERS, {})[recipe.id] = recipe

    def add_subginery(self, subginery: Subginery):
        subginery.set_adapter(self)
        self._entities[subginery.id] = subginery

    def add_enginery(self, enginery: Enginery, recipe_id: int, recipe_type: str):
        enginery.set_adapter(self)

        for manager_id in self._managers:
            if recipe_id in self._managers[manager_id][PROVIDERS]:
                recipe = self.get_recipe(manager_id, recipe_id)
                enginery.set_recipe(recipe_type, recipe)
                recipe.set_ingredient(enginery)
                self._entities[enginery.id] = enginery
                break

==> spread-5.9.0.59-py3-none-any.whl: spread_core/warehouse/equipment_warehouse.py <==
from spread_core.bam.const import *
from spread_core.bam.engineries import Enginery
from spread_core.bam.recipe import Recipe
from spread_core.bam.subgineries.subginery import Subginery
from spread_core.errors.project_errors import EntityNotPresent


class EquipmentWarehouse:
    __slots__ = ['_project_id', '_entities', '_managers']

    def __init__(self, project_id):
        self._project_id = project_id
        self._entities = {}
        self._managers = {}

    def get_entity(self, entity_id: int):
        try:
            return self._entities[entity_id]
        except KeyError:
            raise EntityNotPresent(f'Entity({entity_id}) is not present')

    def get_recipe(self, manager_id: int, provider_id: int) -> Recipe:
        try:
            return self.get_manager(manager_id)[PROVIDERS][provider_id]
        except KeyError:
            raise EntityNotPresent(f'Provider({provider_id}) is not present')

    def all_entities(self) -> tuple:
        yield from self._entities.values()

    def add_manager(self, _id, _type):
        self._managers[_id] = {ID: _id, TYPE: _type, PROVIDERS: {}}

    def get_manager(self, manager_id: int):
        try:
            return self._managers[manager_id]
        except KeyError:
            raise EntityNotPresent(f'Manager({manager_id}) is not present')

    def add_provider(self, recipe: Recipe):
        self._managers[recipe.manager_id].setdefault(PROVIDERS, {})[recipe.id] = recipe

    def add_subginery(self, subginery: Subginery):
        subginery.set_adapter(self)
        self._entities[subginery.location_id] = subginery

    def add_enginery(self, enginery: Enginery, recipe_id: int, recipe_type: str):
        enginery.set_adapter(self)

        for manager_id in self._managers:
            if recipe_id in self._managers[manager_id][PROVIDERS]:
                recipe = self.get_recipe(manager_id, recipe_id)
                enginery.set_recipe(recipe_type, recipe)
                recipe.set_ingredient(enginery)
                self._entities[enginery.id] = enginery
                break
